@@ -2,7 +2,7 @@
  *
  * $Id: filedef.h,v 1.32 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -116,10 +116,7 @@ class FileDef : public Definition
     /*! Returns version of this file. */
     QCString getVersion() const { return fileVersion; }
     
-    bool isLinkableInProject() const
-    {
-      return hasDocumentation() && !isReference();
-    }
+    bool isLinkableInProject() const;
 
     bool isLinkable() const
     {
@@ -128,12 +125,12 @@ class FileDef : public Definition
     bool isIncluded(const QCString &name) const;
 
     bool isJava() const { return m_isJava; }
+    bool isCSharp() const { return m_isCSharp; }
 
-    void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
-    void writeMemberDocumentation(OutputList &ol);
     void writeMemberPages(OutputList &ol);
     void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
+    void writeSummaryLinks(OutputList &ol);
 
     void writeSource(OutputList &ol);
     void parseSource();
@@ -156,6 +153,7 @@ class FileDef : public Definition
     void combineUsingRelations();
 
     bool generateSourceFile() const;
+    void sortMemberLists();
 
     void addIncludeDependency(FileDef *fd,const char *incName,bool local,bool imported);
     void addIncludedByDependency(FileDef *fd,const char *incName,bool local,bool imported);
@@ -169,6 +167,7 @@ class FileDef : public Definition
 
     void addListReferences();
     bool isDocumentationFile() const;
+    bool includes(FileDef *incFile,QDict<FileDef> *includedFiles) const;
 
     MemberList *getMemberList(MemberList::ListType lt) const;
     const QList<MemberList> &getMemberLists() const { return m_memberLists; }
@@ -191,6 +190,20 @@ class FileDef : public Definition
     void addMemberToList(MemberList::ListType lt,MemberDef *md);
     void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title);
     void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
+    void writeIncludeFiles(OutputList &ol);
+    void writeIncludeGraph(OutputList &ol);
+    void writeIncludedByGraph(OutputList &ol);
+    void writeMemberGroups(OutputList &ol);
+    void writeAuthorSection(OutputList &ol);
+    void writeSourceLink(OutputList &ol);
+    void writeNamespaceDeclarations(OutputList &ol,const QCString &title);
+    void writeClassDeclarations(OutputList &ol,const QCString &title);
+    void startMemberDeclarations(OutputList &ol);
+    void endMemberDeclarations(OutputList &ol);
+    void startMemberDocumentation(OutputList &ol);
+    void endMemberDocumentation(OutputList &ol);
+    void writeDetailedDescription(OutputList &ol,const QCString &title);
+    void writeBriefDescription(OutputList &ol);
 
     QDict<IncludeInfo>   *includeDict;
     QList<IncludeInfo>   *includeList;
@@ -207,6 +220,7 @@ class FileDef : public Definition
     QIntDict<MemberDef>  *srcMemberDict;
     bool                  isSource;
     bool                  m_isJava;
+    bool                  m_isCSharp;
     QCString              fileVersion;
     PackageDef           *package;
     DirDef               *dir;
